# ctf-dl

ctf-dl is a command line tool to download CTF challenges.

⚠️ This project is still in development ⚠️

## Installation

```bash
pip install ctf-dl
```

## Basic Usage

```bash
ctf-dl --url https://demo.ctfd.io --username admin --password password
```

## License

MIT License © 2025 bjornmorten
